// From top to bottom of motor driver (bottom is big capacitor)
#define MOTOR_LEFT_PIN_2 D3 // Not using D5 because it gets pulled high briefly on startup
#define MOTOR_LEFT_PIN_1 D6
#define MOTOR_RIGHT_PIN_2 D9
#define MOTOR_RIGHT_PIN_1 D10

#define DEBOUNCE_TIME_MS 50

#define LEFT_MOTOR_SPEED 25
#define RIGHT_MOTOR_SPEED 25

typedef struct {
  float R;
  float G;
  float B;
} Rgb;

typedef struct {
  Rgb min = Rgb{0, 0, 0};
  Rgb max = Rgb{255, 255, 255};
} ColorSensorCal;

void printRGB(const Rgb& value);
void checkButtonPress();
void getColorValues(Rgb& left_value, Rgb& right_value);
float computeHue(const Rgb& rgb);

// mode 0(default) - break, 1 - coast
void motorLeftForward(int speed, bool mode = 0);
void motorLeftBackward(int speed, bool mode = 0);
void motorRightForward(int speed, bool mode = 0);
void motorRightBackward(int speed, bool mode = 0);

typedef enum {
    MODE_BREAK,
    MODE_COAST
} MotorMode;

typedef enum {
    CALIBRATE_BLACK,
    CALIBRATE_WHITE,
    CALIBRATE_READY,
} CalibrationState;
